@@ -255,7 +255,7 @@ var AggregateMenuIndicator = new Lang.Class({
     this._signalsId = [];
     this._primaryIndicator = this._addIndicator();
     this._primaryIndicator.icon_name = 'audio-x-generic-symbolic';
-    this._primaryIndicator.style_class = 'system-status-icon no-padding'
+    this._primaryIndicator.style_class = 'system-status-icon no-padding';
     this._secondaryIndicator = this._addIndicator();
     this._secondaryIndicator.icon_name = 'media-playback-stop-symbolic';
     this._secondaryIndicator.style_class = 'system-status-icon no-padding';
