@@ -61,6 +61,8 @@ var PlayerState = new Lang.Class({
   trackListMetaData: null,
 
   trackTime: null,
+  trackDuration: null,
+  trackPosition: null,
   trackTitle: null,
   trackAlbum: null,
   trackArtist: null,
@@ -496,6 +498,7 @@ var MPRISPlayer = new Lang.Class({
 
           if (props.Metadata) {
             this.parseMetadata(props.Metadata.deep_unpack(), newState);
+            newState.trackDuration = this._formatTime(newState.trackLength)
             newState.emitSignal = true;
             if (newState.trackUrl !== this.state.trackUrl || newState.trackObj !== this.state.trackObj) {
               this._refreshProperties(newState);
@@ -536,7 +539,7 @@ var MPRISPlayer = new Lang.Class({
             // for the new position.
             else {
               let newState = new PlayerState();
-              this._refreshProperties(newState)
+              this._refreshProperties(newState);
             }
           }
         }));
@@ -639,8 +642,11 @@ var MPRISPlayer = new Lang.Class({
       if (this._trackTime >= trackLength) {
         value = 0;
       }
+      let newState = new PlayerState();
       this._trackTime = value;
-      this.emit('update-player-state', new PlayerState({trackTime: this._trackTime}));
+      newState.trackTime = value;
+      newState.trackPosition = this._formatTime(value);      
+      this.emit('update-player-state', newState);
     },
 
     get trackTime() {
@@ -679,6 +685,10 @@ var MPRISPlayer = new Lang.Class({
       return canPause;
     },
 
+    get canQuit() {
+      return this._mediaServer.CanQuit || false;
+    },
+
     get canSeek() {
       return this._mediaServerPlayer.CanSeek || false;
     },
@@ -738,13 +748,13 @@ var MPRISPlayer = new Lang.Class({
     },
 
     get desktopEntry() {
-      return this._mediaServer.DesktopEntry || ''
+      return (this._mediaServer.DesktopEntry || '');
     },
 
     get activePlaylist() {
       let activePlaylist = this._mediaServerPlaylists.ActivePlaylist;
       if (activePlaylist === null || !activePlaylist || !activePlaylist[1]) {
-        activePlaylist = [null, null]
+        activePlaylist = [null, null];
       }
       else {
         activePlaylist = activePlaylist[1];
@@ -851,6 +861,12 @@ var MPRISPlayer = new Lang.Class({
       }
     },
 
+    quit: function() {
+      if (this.canQuit) {
+        this._mediaServer.QuitRemote();
+      }
+    },
+
     _refreshProperties: function(newState) {
       // Check properties
       // Many players have a habit of changing properties without emitting
@@ -1036,7 +1052,7 @@ var MPRISPlayer = new Lang.Class({
       // properties refresh and don't need to do it again. 
       if (!newState.timeFresh) {
         let newState = new PlayerState();
-        this._refreshProperties(newState)
+        this._refreshProperties(newState);
       }
       if (this.state.status == Settings.Status.PLAY) {
         this._startTimer();
@@ -1065,6 +1081,19 @@ var MPRISPlayer = new Lang.Class({
       }
     },
 
+    _formatTime: function(s) {
+      if (Number.isNaN(s) || s < 0) {
+        return '0:00'
+      }
+      let h = Math.floor(s / 3600);
+      let m = Math.floor((s % 3600) / 60);
+      s = s % 60;
+      s = s < 10 ? '0' + s : s;
+      m = m < 10 && h > 0 ? '0' + m + ':' : m + ':';
+      h = h > 0 ? h + ':' : '';
+      return h + m + s;
+    },
+
     destroy: function() {
         // Cancel all pending timeouts.
         this._stopTimer();
